import { EscrowClient } from '..';
import { EventEmitter } from './Emitter.js';
import { MemberController } from './Member.js';
import { ContractParser } from './Parser.js';
import { ProfileController } from './Profile.js';
import { SignatureController } from './Signature.js';
import { ContractConfig, ContractCreate, ContractData, EndorseData, ProfileData, SignatureData } from '../schema/index.js';
export declare class EscrowContract extends EventEmitter {
    static create(client: EscrowClient, template: ContractCreate, config?: Partial<ContractConfig>): Promise<EscrowContract>;
    readonly _cid: string;
    readonly _client: EscrowClient;
    readonly _parser: ContractParser;
    readonly config: ContractConfig;
    _cache?: ContractData;
    refreshed_at?: Date;
    constructor(client: EscrowClient, contract: ContractData, config?: Partial<ContractConfig>);
    get cid(): string;
    get API(): import("../routes/contract").ContractRouter;
    get pubkey(): string;
    get data(): Promise<ContractData>;
    get endorsements(): Promise<EndorseData[]>;
    get members(): Promise<string[]>;
    get profiles(): Promise<ProfileData[]>;
    get signatures(): Promise<SignatureData[]>;
    cache(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }[];
        deposits: {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        };
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        members: string[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        profiles: {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }[];
        return: {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        };
        session: {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }[];
    }>;
    fetch(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }[];
        deposits: {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        };
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        members: string[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        profiles: {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }[];
        return: {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        };
        session: {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }[];
    }>;
    member: MemberController;
    profile: ProfileController;
    signature: SignatureController;
}
//# sourceMappingURL=Contract.d.ts.map