import { EscrowContract } from './Contract.js';
import { ProfileRouter } from '../routes/profile.js';
import { ProfileData, ProfileTemplate } from '../schema/index.js';
export declare class ProfileController {
    readonly _contract: EscrowContract;
    constructor(contract: EscrowContract);
    get API(): ProfileRouter;
    get cid(): string;
    get pubkey(): string;
    get data(): Promise<ProfileData | undefined>;
    refresh(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }[];
        deposits: {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        };
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        members: string[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        profiles: {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }[];
        return: {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        };
        session: {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }[];
    }>;
    list(): Promise<ProfileData[]>;
    create(template: ProfileTemplate): Promise<{
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    } | undefined>;
    set(template: ProfileTemplate): Promise<{
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    } | undefined>;
    update(template: ProfileTemplate): Promise<{
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    } | undefined>;
    remove(): Promise<{
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    } | undefined>;
}
//# sourceMappingURL=Profile.d.ts.map