import { z } from 'zod';
export type ContractData = z.infer<typeof data>;
export type ContractCreate = z.infer<typeof create>;
declare const create: z.ZodObject<{
    value: z.ZodBigInt;
    title: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    terms: z.ZodOptional<z.ZodString>;
    agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    depositor: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    profile: z.ZodOptional<z.ZodObject<{
        alias: z.ZodString;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        nonce: string;
        alias: string;
    }, {
        nonce: string;
        alias: string;
    }>>;
    records: z.ZodOptional<z.ZodArray<z.ZodObject<{
        kind: z.ZodEnum<["data", "script"]>;
        label: z.ZodString;
        content: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        kind: "data" | "script";
        label: string;
        content: string[];
    }, {
        kind: "data" | "script";
        label: string;
        content: string[];
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    value: bigint;
    title: string;
    description?: string | undefined;
    terms?: string | undefined;
    agent?: string | undefined;
    depositor?: string | undefined;
    profile?: {
        nonce: string;
        alias: string;
    } | undefined;
    records?: {
        kind: "data" | "script";
        label: string;
        content: string[];
    }[] | undefined;
}, {
    value: bigint;
    title: string;
    description?: string | undefined;
    terms?: string | undefined;
    agent?: string | undefined;
    depositor?: string | undefined;
    profile?: {
        nonce: string;
        alias: string;
    } | undefined;
    records?: {
        kind: "data" | "script";
        label: string;
        content: string[];
    }[] | undefined;
}>;
declare const data: z.ZodObject<{
    contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
    revision: z.ZodNumber;
    created_at: z.ZodDate;
    updated_at: z.ZodDate;
    claims: z.ZodArray<z.ZodObject<{
        address: z.ZodString;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        script: z.ZodArray<z.ZodString, "many">;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
        updated_at: Date;
    }, {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
        updated_at: Date;
    }>, "many">;
    deposits: z.ZodArray<z.ZodObject<{
        txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        vout: z.ZodNumber;
        value: z.ZodBigInt;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        updated_at: Date;
        txid: string;
        vout: number;
    }, {
        value: bigint;
        updated_at: Date;
        txid: string;
        vout: number;
    }>, "many">;
    details: z.ZodObject<{
        title: z.ZodString;
        description: z.ZodString;
        terms: z.ZodString;
        admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        depositor: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        value: z.ZodBigInt;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        title: string;
        description: string;
        terms: string;
        admin: string;
        agent: string;
        depositor: string;
    }, {
        value: bigint;
        title: string;
        description: string;
        terms: string;
        admin: string;
        agent: string;
        depositor: string;
    }>;
    endorsements: z.ZodArray<z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        updated_at: Date;
        hash: string;
        signature: string;
    }, {
        pubkey: string;
        updated_at: Date;
        hash: string;
        signature: string;
    }>, "many">;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    meta: z.ZodObject<{
        block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        open_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        close_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    }, "strip", z.ZodTypeAny, {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    }, {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    }>;
    profiles: z.ZodArray<z.ZodObject<{
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        alias: z.ZodString;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        tags: z.ZodArray<z.ZodTuple<[z.ZodString, z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean, z.ZodNull]>], null>, "many">;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }, {
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }>, "many">;
    records: z.ZodArray<z.ZodObject<{
        kind: z.ZodEnum<["data", "script"]>;
        label: z.ZodString;
        content: z.ZodArray<z.ZodString, "many">;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        updated_at: Date;
        kind: "data" | "script";
        label: string;
        content: string[];
    }, {
        pubkey: string;
        updated_at: Date;
        kind: "data" | "script";
        label: string;
        content: string[];
    }>, "many">;
    return: z.ZodObject<{
        address: z.ZodString;
        expires: z.ZodNumber;
        script: z.ZodArray<z.ZodString, "many">;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        address: string;
        script: string[];
        updated_at: Date;
        expires: number;
    }, {
        address: string;
        script: string[];
        updated_at: Date;
        expires: number;
    }>;
    session: z.ZodObject<{
        secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        nonce: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        sighash: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        txhex: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
        taptweak: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        updated_at: Date;
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    }, {
        updated_at: Date;
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    }>;
    signatures: z.ZodArray<z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        updated_at: Date;
        hash: string;
        psig: string;
    }, {
        pubkey: string;
        updated_at: Date;
        hash: string;
        psig: string;
    }>, "many">;
    transactions: z.ZodArray<z.ZodObject<{
        confirmed: z.ZodBoolean;
        type: z.ZodEnum<["claim", "deposit", "refund", "settlement"]>;
        txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        txhex: z.ZodEffects<z.ZodString, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        type: "claim" | "deposit" | "refund" | "settlement";
        updated_at: Date;
        txid: string;
        txhex: string;
        confirmed: boolean;
    }, {
        type: "claim" | "deposit" | "refund" | "settlement";
        updated_at: Date;
        txid: string;
        txhex: string;
        confirmed: boolean;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    updated_at: Date;
    contract_id: string;
    revision: number;
    created_at: Date;
    claims: {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
        updated_at: Date;
    }[];
    deposits: {
        value: bigint;
        updated_at: Date;
        txid: string;
        vout: number;
    }[];
    details: {
        value: bigint;
        title: string;
        description: string;
        terms: string;
        admin: string;
        agent: string;
        depositor: string;
    };
    endorsements: {
        pubkey: string;
        updated_at: Date;
        hash: string;
        signature: string;
    }[];
    members: string[];
    meta: {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    };
    profiles: {
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }[];
    records: {
        pubkey: string;
        updated_at: Date;
        kind: "data" | "script";
        label: string;
        content: string[];
    }[];
    return: {
        address: string;
        script: string[];
        updated_at: Date;
        expires: number;
    };
    session: {
        updated_at: Date;
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    };
    signatures: {
        pubkey: string;
        updated_at: Date;
        hash: string;
        psig: string;
    }[];
    transactions: {
        type: "claim" | "deposit" | "refund" | "settlement";
        updated_at: Date;
        txid: string;
        txhex: string;
        confirmed: boolean;
    }[];
}, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    updated_at: Date;
    contract_id: string;
    revision: number;
    created_at: Date;
    claims: {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
        updated_at: Date;
    }[];
    deposits: {
        value: bigint;
        updated_at: Date;
        txid: string;
        vout: number;
    }[];
    details: {
        value: bigint;
        title: string;
        description: string;
        terms: string;
        admin: string;
        agent: string;
        depositor: string;
    };
    endorsements: {
        pubkey: string;
        updated_at: Date;
        hash: string;
        signature: string;
    }[];
    members: string[];
    meta: {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    };
    profiles: {
        pubkey: string;
        nonce: string;
        updated_at: Date;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }[];
    records: {
        pubkey: string;
        updated_at: Date;
        kind: "data" | "script";
        label: string;
        content: string[];
    }[];
    return: {
        address: string;
        script: string[];
        updated_at: Date;
        expires: number;
    };
    session: {
        updated_at: Date;
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    };
    signatures: {
        pubkey: string;
        updated_at: Date;
        hash: string;
        psig: string;
    }[];
    transactions: {
        type: "claim" | "deposit" | "refund" | "settlement";
        updated_at: Date;
        txid: string;
        txhex: string;
        confirmed: boolean;
    }[];
}>;
export declare const ContractSchema: {
    create: z.ZodObject<{
        value: z.ZodBigInt;
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        terms: z.ZodOptional<z.ZodString>;
        agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        depositor: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        profile: z.ZodOptional<z.ZodObject<{
            alias: z.ZodString;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            nonce: string;
            alias: string;
        }, {
            nonce: string;
            alias: string;
        }>>;
        records: z.ZodOptional<z.ZodArray<z.ZodObject<{
            kind: z.ZodEnum<["data", "script"]>;
            label: z.ZodString;
            content: z.ZodArray<z.ZodString, "many">;
        }, "strip", z.ZodTypeAny, {
            kind: "data" | "script";
            label: string;
            content: string[];
        }, {
            kind: "data" | "script";
            label: string;
            content: string[];
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
        agent?: string | undefined;
        depositor?: string | undefined;
        profile?: {
            nonce: string;
            alias: string;
        } | undefined;
        records?: {
            kind: "data" | "script";
            label: string;
            content: string[];
        }[] | undefined;
    }, {
        value: bigint;
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
        agent?: string | undefined;
        depositor?: string | undefined;
        profile?: {
            nonce: string;
            alias: string;
        } | undefined;
        records?: {
            kind: "data" | "script";
            label: string;
            content: string[];
        }[] | undefined;
    }>;
    data: z.ZodObject<{
        contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
        revision: z.ZodNumber;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
        claims: z.ZodArray<z.ZodObject<{
            address: z.ZodString;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            script: z.ZodArray<z.ZodString, "many">;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }, {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }>, "many">;
        deposits: z.ZodArray<z.ZodObject<{
            txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            vout: z.ZodNumber;
            value: z.ZodBigInt;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }, {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }>, "many">;
        details: z.ZodObject<{
            title: z.ZodString;
            description: z.ZodString;
            terms: z.ZodString;
            admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            depositor: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            value: z.ZodBigInt;
        }, "strip", z.ZodTypeAny, {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        }, {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        }>;
        endorsements: z.ZodArray<z.ZodObject<{
            hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }, {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }>, "many">;
        members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
        meta: z.ZodObject<{
            block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            open_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            close_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        }, "strip", z.ZodTypeAny, {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        }, {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        }>;
        profiles: z.ZodArray<z.ZodObject<{
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            alias: z.ZodString;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            tags: z.ZodArray<z.ZodTuple<[z.ZodString, z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean, z.ZodNull]>], null>, "many">;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }, {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }>, "many">;
        records: z.ZodArray<z.ZodObject<{
            kind: z.ZodEnum<["data", "script"]>;
            label: z.ZodString;
            content: z.ZodArray<z.ZodString, "many">;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }, {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }>, "many">;
        return: z.ZodObject<{
            address: z.ZodString;
            expires: z.ZodNumber;
            script: z.ZodArray<z.ZodString, "many">;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        }, {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        }>;
        session: z.ZodObject<{
            secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            nonce: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            sighash: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            txhex: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            taptweak: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        }, {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        }>;
        signatures: z.ZodArray<z.ZodObject<{
            hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }, {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }>, "many">;
        transactions: z.ZodArray<z.ZodObject<{
            confirmed: z.ZodBoolean;
            type: z.ZodEnum<["claim", "deposit", "refund", "settlement"]>;
            txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            txhex: z.ZodEffects<z.ZodString, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }, {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }[];
        deposits: {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        };
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        members: string[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        profiles: {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }[];
        return: {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        };
        session: {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }[];
    }, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
            updated_at: Date;
        }[];
        deposits: {
            value: bigint;
            updated_at: Date;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            title: string;
            description: string;
            terms: string;
            admin: string;
            agent: string;
            depositor: string;
        };
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        members: string[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        profiles: {
            pubkey: string;
            nonce: string;
            updated_at: Date;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            updated_at: Date;
            kind: "data" | "script";
            label: string;
            content: string[];
        }[];
        return: {
            address: string;
            script: string[];
            updated_at: Date;
            expires: number;
        };
        session: {
            updated_at: Date;
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "claim" | "deposit" | "refund" | "settlement";
            updated_at: Date;
            txid: string;
            txhex: string;
            confirmed: boolean;
        }[];
    }>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
};
export {};
//# sourceMappingURL=contract.d.ts.map